from setuptools import setup

setup(name='pizaa', version=0.21, description='Python image to ascii-art library', packages=['pizaa'], author_email='mrtnb1998@gmail.com', zip_safe=False, author='Kollob')


''' , description='A python image to ascii art library\nIt`s usage is simple:\n\tITAA: class with all functions of module\n\tITAA.itaa(img[, rescale, mode, output, use_spaces, invert, enlarge]): image to ascii art function. If mode is \'save\' save`s text to output, else returns it\n\tITAA._itaa(img[, rescale, mode, output, invert, enlarge]): old itaa function, with old 25 symbols pallete (new one have 51 symbols)\n\tITAA.restore_grayscale(img[, output]): restores grayscale from text, generated by new itaa function' '''
